==> haskell-sourcemap-0.1.7-291.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-DZD66zR4CFYECthT0J3B5w
key:                  sourcemap-0.1.7-DZD66zR4CFYECthT0J3B5w
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  83bd6b861e1049c560cd2f05b32381a8
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-DZD66zR4CFYECthT0J3B5w
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 process-1.6.19.0 text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.7-292-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-7FaKubr3SZ690nsldmOIiI
key:                  sourcemap-0.1.7-7FaKubr3SZ690nsldmOIiI
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  f3e360b8cfcc94f9bd118369e5e3f292
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-7FaKubr3SZ690nsldmOIiI
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 process-1.6.19.0 text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
